@@ -9,7 +9,9 @@ from spark_auto_mapper.automappers.automapper_base import AutoMapperBase
 
 from spark_pipeline_framework.logger.yarn_logger import get_logger
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
-from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import FrameworkTransformer
+from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
+    FrameworkTransformer,
+)
 
 # define type for AutoMapperFunction
 AutoMapperTypeOrList = Union[AutoMapperBase, List[AutoMapperBase]]
@@ -25,7 +27,7 @@ class FrameworkMappingLoader(FrameworkTransformer):
         mapping_function: AutoMapperFunction,
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
-        progress_logger: Optional[ProgressLogger] = None
+        progress_logger: Optional[ProgressLogger] = None,
     ) -> None:
         super().__init__(
             name=name, parameters=parameters, progress_logger=progress_logger
@@ -43,8 +45,7 @@ class FrameworkMappingLoader(FrameworkTransformer):
         kwargs = self._input_kwargs
         # remove mapping_function since that is not serializable
         kwargs = {
-            key: value
-            for key, value in kwargs.items() if key != "mapping_function"
+            key: value for key, value in kwargs.items() if key != "mapping_function"
         }
         self.setParams(**kwargs)
 
@@ -55,7 +56,7 @@ class FrameworkMappingLoader(FrameworkTransformer):
         view: str,
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
-        progress_logger: Optional[ProgressLogger] = None
+        progress_logger: Optional[ProgressLogger] = None,
     ) -> Any:
         # noinspection Mypy
         kwargs = self._input_kwargs
@@ -71,9 +72,9 @@ class FrameworkMappingLoader(FrameworkTransformer):
 
         # run the mapping function to get an AutoMapper
         incoming_parameters: Optional[Dict[str, Any]] = self.getParameters()
-        parameters: Dict[
-            str,
-            Any] = incoming_parameters.copy() if incoming_parameters else {}
+        parameters: Dict[str, Any] = (
+            incoming_parameters.copy() if incoming_parameters else {}
+        )
         parameters["view"] = view
 
         auto_mappers: List[AutoMapperBase] = []
